@@ -13,7 +13,7 @@ Geom <- proto(TopLevel, expr={
 
 	draw <- function(...) {}
 	draw_groups <- function(., data, scales, coordinates, ...) {
-		if (nrow(data) == 0) return(NULL)
+		if (is.null(data) || nrow(data) == 0) return()
 		groups <- split(data, factor(data$group))
 		grobs <- lapply(groups, function(group) .$draw(group, scales, coordinates, ...))
 		
