@@ -8,4 +8,9 @@ GeomBlank <- proto(Geom, {
 	desc <- "Blank, draws nothing"
 	detail <- "<p>The blank geom draws nothing, but can be a useful way of ensuring common scales between different plots</p>\n"
 	
+	examples <- function(.) {
+		qplot(length, rating, data=movies, geom="blank")
+		# Nothing to see here!
+	}
+	
 })
