@@ -3,7 +3,7 @@ GeomHline <- proto(Geom, {
 		if (missing(data)) {
 			data <- data.frame(intercept = intercept)
 		}
-		mapping <- defaults(mapping, aes(intercept=intercept))
+		mapping <- defaults(mapping, aes(intercept=intercept, x=NULL, y=NULL))
 		layer(mapping=mapping, data=data, geom = ., geom_params = list(...))
 	}
 
@@ -22,7 +22,8 @@ GeomHline <- proto(Geom, {
 	objname <- "hline"
 	desc <- "Line, horizontal"
 	icon <- function(.) linesGrob(c(0, 1), c(0.5, 0.5))
-	
+	details <- "<p>This geom allows you to annotate the plot with horizontal lines (see geom_vline and geom_abline for other types of lines)</p>\n\n<p>There are two ways to use it.  You can either specify the intercept of the line in the call to the geom, in which case the line will be in the same position in every panel.  Alternatively, you can supply a different intercept for each panel using a data.frame.  See the examples for the differences</p>"
+		
 	default_stat <- function(.) StatIdentity
 	default_aes <- function(.) c(GeomPath$default_aes(), aes(intercept=0))
 	
